==> viqcore_flutter-1.3.1.tar.gz: lib/src/app.dart <==
import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:hive_flutter/hive_flutter.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'security/passport.dart';

export 'entities/entities.dart';
export 'extension/extension.dart';
export 'helper/helper.dart';
export 'http_client/api.dart';
export 'security/crypto.dart';
export 'security/passport.dart';
export 'upgrader/upgrader.dart';

// ignore: non_constant_identifier_names
final App = AppService._();

//AppService get App => GetIt.instance<AppService>();

class AppService {
  AppService._();

  // static Future<void> ensureInitialized() async {
  //   WidgetsFlutterBinding.ensureInitialized();
  //   await Hive.initFlutter();
  //   await Hive.openBox<String>('defaultBox');
  //   GetIt.I.allowReassignment = true;
  //   GetIt.I.registerSingleton(AppService._());
  //   GetIt.I.registerSingleton<Credential>(DefaultCredentialService());
  //   GetIt.I.registerSingleton(await PackageInfo.fromPlatform());
  // }

  late final Box<String> box = Hive.box<String>(packageInfo.packageName);
  final GetIt getIt = GetIt.instance;
  Passport get passport => GetIt.instance<Passport>();
  PackageInfo get packageInfo => GetIt.instance<PackageInfo>();

  void registerService<T extends Object>(T instance) {
    getIt.registerSingleton<T>(instance);
  }

  //bool _bootstraped = false;
  Future<void> bootstrap(
      [AppBootstrap bootstrap = const AppBootstrap()]) async {
    GetIt.I.allowReassignment = true;
    WidgetsFlutterBinding.ensureInitialized();
    await bootstrap.execute();
    GetIt.I.allowReassignment = false;
    //_bootstraped = true;
  }

  /// Callable class so that you can write `App<MyServiceType>` instead of
  /// `App.getIt<MyType>`
  T call<T extends Object>() {
    return getIt<T>();
  }
}

class AppBootstrap {
  const AppBootstrap();

  @mustCallSuper
  @protected
  Future<void> execute() async {
    var packageInfo = await PackageInfo.fromPlatform();
    GetIt.I.registerSingleton(packageInfo);
    await Hive.initFlutter();
    await Hive.openBox<String>(packageInfo.packageName);
    GetIt.I.registerSingleton<Passport>(DefaultPassport());
  }
}

==> viqcore_flutter-1.5.3.tar.gz: lib/src/app.dart <==
import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:hive_flutter/hive_flutter.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'security/passport.dart';

export 'entities/entities.dart';
export 'extensions/_.dart';
export 'helper/helper.dart';
export 'http_client/api.dart';
export 'security/crypto.dart';
export 'security/passport.dart';
export 'upgrader/upgrader.dart';

// ignore: non_constant_identifier_names
final App = AppService._();

//AppService get App => GetIt.instance<AppService>();

class AppService {
  AppService._();

  // static Future<void> ensureInitialized() async {
  //   WidgetsFlutterBinding.ensureInitialized();
  //   await Hive.initFlutter();
  //   await Hive.openBox<String>('defaultBox');
  //   GetIt.I.allowReassignment = true;
  //   GetIt.I.registerSingleton(AppService._());
  //   GetIt.I.registerSingleton<Credential>(DefaultCredentialService());
  //   GetIt.I.registerSingleton(await PackageInfo.fromPlatform());
  // }

  late final Box<String> box = Hive.box<String>(packageInfo.packageName);
  final GetIt getIt = GetIt.instance;
  Passport get passport => GetIt.instance<Passport>();
  PackageInfo get packageInfo => GetIt.instance<PackageInfo>();

  void registerService<T extends Object>(T instance) {
    getIt.registerSingleton<T>(instance);
  }

  //bool _bootstraped = false;
  Future<void> bootstrap(
      [AppBootstrap bootstrap = const AppBootstrap()]) async {
    GetIt.I.allowReassignment = true;
    WidgetsFlutterBinding.ensureInitialized();
    await bootstrap.execute();
    GetIt.I.allowReassignment = false;
    //_bootstraped = true;
  }

  /// Callable class so that you can write `App<MyServiceType>` instead of
  /// `App.getIt<MyType>`
  T call<T extends Object>() {
    return getIt<T>();
  }
}

class AppBootstrap {
  const AppBootstrap();

  @mustCallSuper
  @protected
  Future<void> execute() async {
    var packageInfo = await PackageInfo.fromPlatform();
    GetIt.I.registerSingleton(packageInfo);
    await Hive.initFlutter();
    await Hive.openBox<String>(packageInfo.packageName);
    GetIt.I.registerSingleton<Passport>(DefaultPassport());
  }
}
